Brookdale Community College, Lincroft, New JerseyBrookdale Community College
Description: The County College of Monmouth, Brookdale is New Jersey's #1 Associate Degree granting college, offering over 90 degree and certificate programs of study.

MyBrookdale

###### JUMPstart to Spring Term! Attend a one-stop session on Dec. 11 or Jan. 15

Read More

###### Interested in transferring to Rutgers New Brunswick? Stop by an Info Session on Mon., Dec. 15

Read More

###### Winter is coming.... sign up for text alerts on weather closings and more.

Read More

###### Open Registration for Winterim & Spring Terms ongoing now

Read More

###### Brookdale Welcomes New Interim Vice President

Read More

###### Please stop by and take a card from one of our Giving Trees this year!

Read More

###### Open Registration for Winterim & Spring Terms ongoing now

Read More

###### First day of Spring Term classes is Tuesday, January 21

Read More

### Brookdale’s Visiting Artist Program presents Nell Painter on Thursday, Dec. 4

The Brookdale Visiting Artist Program presents artist Nell Painter speaking on her work and creative process, in a guest lecture beginning at 7 PM in the Center for the Visual Arts Gallery. Click through for details.

Find out more

### festivALL in the Performing Arts Center showcases student achievements

Come to festivALL – a showcase of one-act plays and vocal performances by students in our Directing, Acting, Technical and Voice classes. A great opportunity for students to share their work and experience the excitement of putting on a public performance! From December 4 - 7; click through for information.

Find out more

### On Display in the Center for the Visual Arts Gallery: Observing Connections, through Dec. 5

“Observing Connections: Photographs from the Teaching Collection and Invited Photographers” is on display in the Center for the Visual Arts Gallery, through Dec. 5. The exhibit is free and open to the public; click through for more details.

Find out more

### Anti-Stress Week for Students taking Finals and Finishing Coursework is Dec. 8-12

Take a break from the run-up to finals and end of term, with Student Activities' Anti Stress Week activities - snacks, games, crafts, massage therapy, live music, therapy dogs and more! Click through for dates and details.

Find out more

### Visiting Writers Series: Final Fall Guest Lecture on Wednesday, Dec. 10

Poets Taije Silverman and Jeffrey McDaniel will read from and discuss their work at 7 PM in the Warner Center in the last lecture of the Fall 2014 Visiting Writers Series. Click through for more information.

Find out more

### Concordia Chorale Performs on Sunday, Dec. 14 at 7 PM in the Performing Arts Center

The 40-voice Concordia Chorale, founded in 2001, specializes in the masterworks of the classic choral repertory including major oratorios by Handel, Bach, Mozart, Haydn, and Brahms, along with works by contemporary composers. Free and open to all; click through for more details.

Find out more

### Info Session on Monday, Dec. 15: Transferring to Rutgers New Brunswick

Stop by an Information Session on Monday, Dec. 15, from 10 – 11:30 AM in the Ft. Hancock Room, Warner Student Life Center, and bring your questions about transferring to Rutgers. Ms. Marcie Rosas, Assistant Director for Undergraduate Admissions at Rutgers, will be available to advise you.

Find out more

### Book Signing Event with Illustrator Frank Caruso, on Thursday, Dec. 18 at 7 PM

Caruso, illustrator of the recently published Bruce Springsteen children's book Outlaw Pete, will discuss his art and sign copies of the book, at the Scroll & Pen Bookstore. Free and open to all; click through for more details.

Find out more
Search For Classes Apply To Brookdale Canvas LMS Login

  Events
  News

- - 04
    Dec
    Walk-in Counseling @ Long Branch Center

    10:00 AM - 4:30 PM

  - 04
    Dec
    Walk-In Advising at Wall

    11:00 AM - 6:30 PM

  - 04
    Dec
    Massage Therapy at the Regional Locations

    11:00 AM - 5:00 PM

  - 04
    Dec
    Communiversity–Rutgers Information Session

    3:00 PM - 5:00 PM

  - 04
    Dec
    FYE Passports Due

    5:00 PM - 5:00 PM

  - 04
    Dec
    Brookdale’s Visiting Artist Program presents Nell Painter

    7:00 PM - 9:00 PM

  - 04
    Dec
    festivALL

    7:00 PM - 9:30 PM

  - View All Events

    View All Events

- - ###### Ready to start at Brookdale? JUMPstart to Spring Term

    Ready to start at Brookdale this January? Attend a JUMPstart session for new students and get everything done in one stop - application,

    Find out more

  - ###### Fun Anti-Stress Week Activities from Dec. 8 – 12

    Take a break from studying, finals, and end of term coursework! Monday, Dec. 8 -Snack your Stress Away at the Bankier Library with warm

    Find out more

  - ###### Textbook Buyback, Main Campus and Regional Locations

    Sell your books for cash! Bring in your textbooks and get up to 50% cash back. Textbook Buyback at the Higher Education Centers will be held

    Find out more

  - ###### The Giving Tree at Brookdale, 2014 Holidays

    Please stop by and take a card from one of our Giving Trees this year! In Monmouth County there are many children, and families, who are

    Find out more

  - View All News

- ###### What do you want to be?

  Career Coach helps you explore your career options, view local job openings, build a résumé, and - most importantly - see how courses and degree options from Brookdale can help you reach your goal.

  Find out more

- ###### Take an Online Course

  You can earn eight different degrees, fully online, or take a single class.

  Find out more

- ###### All Locations

  Brookdale in Freehold, Hazlet, Long Branch, Neptune, Wall, and Lincroft.

  Find out more